Struct Cloned

struct Cloned<I: ParallelIterator> { ... }

Cloned is an iterator that clones the elements of an underlying iterator.

This struct is created by the cloned() method on ParallelIterator

Implementations

impl<'a, T, I> IndexedParallelIterator for Cloned<I>

fn drive<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: Consumer<<Self as >::Item>
fn len(self: &Self) -> usize
fn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output
where
    CB: ProducerCallback<<Self as >::Item>

impl<'a, T, I> ParallelIterator for Cloned<I>

fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: UnindexedConsumer<<Self as >::Item>
fn opt_len(self: &Self) -> Option<usize>

impl<I> Freeze for Cloned<I>

impl<I> RefUnwindSafe for Cloned<I>

impl<I> Send for Cloned<I>

impl<I> Sync for Cloned<I>

impl<I> Unpin for Cloned<I>

impl<I> UnsafeUnpin for Cloned<I>

impl<I> UnwindSafe for Cloned<I>

impl<I: $crate::clone::Clone + ParallelIterator> Clone for Cloned<I>

fn clone(self: &Self) -> Cloned<I>

impl<I: $crate::fmt::Debug + ParallelIterator> Debug for Cloned<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Cloned<I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Cloned<I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Cloned<I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Cloned<I>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Cloned<I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoParallelIterator for Cloned<I>

fn into_par_iter(self: Self) -> T

impl<T> Pointable for Cloned<I>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for Cloned<I>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Cloned<I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Cloned<I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Cloned<I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>