Struct FoldChunks

struct FoldChunks<I, ID, F> { ... }
where
    I: IndexedParallelIterator

FoldChunks is an iterator that groups elements of an underlying iterator and applies a function over them, producing a single value for each group.

This struct is created by the fold_chunks() method on IndexedParallelIterator

Implementations

impl<I, ID, F> Freeze for FoldChunks<I, ID, F>

impl<I, ID, F> RefUnwindSafe for FoldChunks<I, ID, F>

impl<I, ID, F> Send for FoldChunks<I, ID, F>

impl<I, ID, F> Sync for FoldChunks<I, ID, F>

impl<I, ID, F> Unpin for FoldChunks<I, ID, F>

impl<I, ID, F> UnsafeUnpin for FoldChunks<I, ID, F>

impl<I, ID, F> UnwindSafe for FoldChunks<I, ID, F>

impl<I, ID, U, F> IndexedParallelIterator for FoldChunks<I, ID, F>

fn len(self: &Self) -> usize
fn drive<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: Consumer<<Self as >::Item>
fn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output
where
    CB: ProducerCallback<<Self as >::Item>

impl<I, ID, U, F> ParallelIterator for FoldChunks<I, ID, F>

fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: Consumer<U>
fn opt_len(self: &Self) -> Option<usize>

impl<I, ID: $crate::clone::Clone, F: $crate::clone::Clone> Clone for FoldChunks<I, ID, F>

fn clone(self: &Self) -> FoldChunks<I, ID, F>

impl<I: IndexedParallelIterator + Debug, ID, F> Debug for FoldChunks<I, ID, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for FoldChunks<I, ID, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FoldChunks<I, ID, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FoldChunks<I, ID, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FoldChunks<I, ID, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FoldChunks<I, ID, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoParallelIterator for FoldChunks<I, ID, F>

fn into_par_iter(self: Self) -> T

impl<T> Pointable for FoldChunks<I, ID, F>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for FoldChunks<I, ID, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for FoldChunks<I, ID, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FoldChunks<I, ID, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FoldChunks<I, ID, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>