Struct FoldChunksWith
struct FoldChunksWith<I, U, F> { ... }
where
I: IndexedParallelIterator
FoldChunksWith is an iterator that groups elements of an underlying iterator and applies a
function over them, producing a single value for each group.
This struct is created by the fold_chunks_with() method on IndexedParallelIterator
Implementations
impl<I, U, F> Freeze for FoldChunksWith<I, U, F>
impl<I, U, F> IndexedParallelIterator for FoldChunksWith<I, U, F>
fn len(self: &Self) -> usizefn drive<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<<Self as >::Item>fn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<I, U, F> ParallelIterator for FoldChunksWith<I, U, F>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<U>fn opt_len(self: &Self) -> Option<usize>
impl<I, U, F> RefUnwindSafe for FoldChunksWith<I, U, F>
impl<I, U, F> Send for FoldChunksWith<I, U, F>
impl<I, U, F> Sync for FoldChunksWith<I, U, F>
impl<I, U, F> Unpin for FoldChunksWith<I, U, F>
impl<I, U, F> UnsafeUnpin for FoldChunksWith<I, U, F>
impl<I, U, F> UnwindSafe for FoldChunksWith<I, U, F>
impl<I, U: $crate::clone::Clone, F: $crate::clone::Clone> Clone for FoldChunksWith<I, U, F>
fn clone(self: &Self) -> FoldChunksWith<I, U, F>
impl<I: IndexedParallelIterator + Debug, U: Debug, F> Debug for FoldChunksWith<I, U, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for FoldChunksWith<I, U, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FoldChunksWith<I, U, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FoldChunksWith<I, U, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for FoldChunksWith<I, U, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for FoldChunksWith<I, U, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for FoldChunksWith<I, U, F>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for FoldChunksWith<I, U, F>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for FoldChunksWith<I, U, F>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for FoldChunksWith<I, U, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FoldChunksWith<I, U, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FoldChunksWith<I, U, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>