Struct Intersperse
struct Intersperse<I> { ... }
where
I: ParallelIterator,
<I as >::Item: Clone
Intersperse is an iterator that inserts a particular item between each
item of the adapted iterator. This struct is created by the
intersperse() method on ParallelIterator
Implementations
impl<I> Clone for Intersperse<I>
fn clone(self: &Self) -> Intersperse<I>
impl<I> Debug for Intersperse<I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I> Freeze for Intersperse<I>
impl<I> IndexedParallelIterator for Intersperse<I>
fn drive<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<<Self as >::Item>fn len(self: &Self) -> usizefn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<I> ParallelIterator for Intersperse<I>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<I as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<I> RefUnwindSafe for Intersperse<I>
impl<I> Send for Intersperse<I>
impl<I> Sync for Intersperse<I>
impl<I> Unpin for Intersperse<I>
impl<I> UnsafeUnpin for Intersperse<I>
impl<I> UnwindSafe for Intersperse<I>
impl<T> Any for Intersperse<I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Intersperse<I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Intersperse<I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Intersperse<I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Intersperse<I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for Intersperse<I>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for Intersperse<I>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for Intersperse<I>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Intersperse<I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Intersperse<I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Intersperse<I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>