Struct MapInit
struct MapInit<I: ParallelIterator, INIT, F> { ... }
MapInit is an iterator that transforms the elements of an underlying iterator.
This struct is created by the map_init() method on ParallelIterator
Implementations
impl<I, INIT, F> Freeze for MapInit<I, INIT, F>
impl<I, INIT, F> RefUnwindSafe for MapInit<I, INIT, F>
impl<I, INIT, F> Send for MapInit<I, INIT, F>
impl<I, INIT, F> Sync for MapInit<I, INIT, F>
impl<I, INIT, F> Unpin for MapInit<I, INIT, F>
impl<I, INIT, F> UnsafeUnpin for MapInit<I, INIT, F>
impl<I, INIT, F> UnwindSafe for MapInit<I, INIT, F>
impl<I, INIT, T, F, R> IndexedParallelIterator for MapInit<I, INIT, F>
fn drive<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<<Self as >::Item>fn len(self: &Self) -> usizefn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<I, INIT, T, F, R> ParallelIterator for MapInit<I, INIT, F>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<I: $crate::clone::Clone + ParallelIterator, INIT: $crate::clone::Clone, F: $crate::clone::Clone> Clone for MapInit<I, INIT, F>
fn clone(self: &Self) -> MapInit<I, INIT, F>
impl<I: ParallelIterator + Debug, INIT, F> Debug for MapInit<I, INIT, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for MapInit<I, INIT, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for MapInit<I, INIT, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for MapInit<I, INIT, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for MapInit<I, INIT, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for MapInit<I, INIT, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for MapInit<I, INIT, F>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for MapInit<I, INIT, F>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for MapInit<I, INIT, F>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for MapInit<I, INIT, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for MapInit<I, INIT, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for MapInit<I, INIT, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>