Struct SkipAnyWhile

struct SkipAnyWhile<I: ParallelIterator, P> { ... }

SkipAnyWhile is an iterator that skips over elements from anywhere in I until the callback returns false. This struct is created by the skip_any_while() method on ParallelIterator

Implementations

impl<I, P> Freeze for SkipAnyWhile<I, P>

impl<I, P> ParallelIterator for SkipAnyWhile<I, P>

fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: UnindexedConsumer<<Self as >::Item>

impl<I, P> RefUnwindSafe for SkipAnyWhile<I, P>

impl<I, P> Send for SkipAnyWhile<I, P>

impl<I, P> Sync for SkipAnyWhile<I, P>

impl<I, P> Unpin for SkipAnyWhile<I, P>

impl<I, P> UnsafeUnpin for SkipAnyWhile<I, P>

impl<I, P> UnwindSafe for SkipAnyWhile<I, P>

impl<I: $crate::clone::Clone + ParallelIterator, P: $crate::clone::Clone> Clone for SkipAnyWhile<I, P>

fn clone(self: &Self) -> SkipAnyWhile<I, P>

impl<I: ParallelIterator + fmt::Debug, P> Debug for SkipAnyWhile<I, P>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for SkipAnyWhile<I, P>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SkipAnyWhile<I, P>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SkipAnyWhile<I, P>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for SkipAnyWhile<I, P>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for SkipAnyWhile<I, P>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoParallelIterator for SkipAnyWhile<I, P>

fn into_par_iter(self: Self) -> T

impl<T> Pointable for SkipAnyWhile<I, P>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for SkipAnyWhile<I, P>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for SkipAnyWhile<I, P>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SkipAnyWhile<I, P>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SkipAnyWhile<I, P>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>