Struct Split

struct Split<D, S> { ... }

Split is a parallel iterator using arbitrary data and a splitting function. This struct is created by the split() function.

Implementations

impl<D, S> Freeze for Split<D, S>

impl<D, S> ParallelIterator for Split<D, S>

fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: UnindexedConsumer<<Self as >::Item>

impl<D, S> RefUnwindSafe for Split<D, S>

impl<D, S> Send for Split<D, S>

impl<D, S> Sync for Split<D, S>

impl<D, S> Unpin for Split<D, S>

impl<D, S> UnsafeUnpin for Split<D, S>

impl<D, S> UnwindSafe for Split<D, S>

impl<D: $crate::clone::Clone, S: $crate::clone::Clone> Clone for Split<D, S>

fn clone(self: &Self) -> Split<D, S>

impl<D: Debug, S> Debug for Split<D, S>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Split<D, S>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Split<D, S>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Split<D, S>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Split<D, S>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Split<D, S>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoParallelIterator for Split<D, S>

fn into_par_iter(self: Self) -> T

impl<T> Pointable for Split<D, S>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for Split<D, S>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Split<D, S>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Split<D, S>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Split<D, S>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>