Struct StepBy

struct StepBy<I: IndexedParallelIterator> { ... }

StepBy is an iterator that skips n elements between each yield, where n is the given step. This struct is created by the step_by() method on IndexedParallelIterator

Implementations

impl<I> Freeze for StepBy<I>

impl<I> IndexedParallelIterator for StepBy<I>

fn drive<C: Consumer<<Self as >::Item>>(self: Self, consumer: C) -> <C as >::Result
fn len(self: &Self) -> usize
fn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output
where
    CB: ProducerCallback<<Self as >::Item>

impl<I> ParallelIterator for StepBy<I>

fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: UnindexedConsumer<<Self as >::Item>
fn opt_len(self: &Self) -> Option<usize>

impl<I> RefUnwindSafe for StepBy<I>

impl<I> Send for StepBy<I>

impl<I> Sync for StepBy<I>

impl<I> Unpin for StepBy<I>

impl<I> UnsafeUnpin for StepBy<I>

impl<I> UnwindSafe for StepBy<I>

impl<I: $crate::clone::Clone + IndexedParallelIterator> Clone for StepBy<I>

fn clone(self: &Self) -> StepBy<I>

impl<I: $crate::fmt::Debug + IndexedParallelIterator> Debug for StepBy<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for StepBy<I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for StepBy<I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for StepBy<I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for StepBy<I>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for StepBy<I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoParallelIterator for StepBy<I>

fn into_par_iter(self: Self) -> T

impl<T> Pointable for StepBy<I>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for StepBy<I>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for StepBy<I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for StepBy<I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for StepBy<I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>