Struct Take

struct Take<I> { ... }

Take is an iterator that iterates over the first n elements. This struct is created by the take() method on IndexedParallelIterator

Implementations

impl<I> Freeze for Take<I>

impl<I> IndexedParallelIterator for Take<I>

fn len(self: &Self) -> usize
fn drive<C: Consumer<<Self as >::Item>>(self: Self, consumer: C) -> <C as >::Result
fn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output
where
    CB: ProducerCallback<<Self as >::Item>

impl<I> ParallelIterator for Take<I>

fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: UnindexedConsumer<<Self as >::Item>
fn opt_len(self: &Self) -> Option<usize>

impl<I> RefUnwindSafe for Take<I>

impl<I> Send for Take<I>

impl<I> Sync for Take<I>

impl<I> Unpin for Take<I>

impl<I> UnsafeUnpin for Take<I>

impl<I> UnwindSafe for Take<I>

impl<I: $crate::clone::Clone> Clone for Take<I>

fn clone(self: &Self) -> Take<I>

impl<I: $crate::fmt::Debug> Debug for Take<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Take<I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Take<I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Take<I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Take<I>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Take<I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoParallelIterator for Take<I>

fn into_par_iter(self: Self) -> T

impl<T> Pointable for Take<I>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for Take<I>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Take<I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Take<I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Take<I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>