Struct TakeAny

struct TakeAny<I: ParallelIterator> { ... }

TakeAny is an iterator that iterates over n elements from anywhere in I. This struct is created by the take_any() method on ParallelIterator

Implementations

impl<I> Freeze for TakeAny<I>

impl<I> ParallelIterator for TakeAny<I>

fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: UnindexedConsumer<<Self as >::Item>

impl<I> RefUnwindSafe for TakeAny<I>

impl<I> Send for TakeAny<I>

impl<I> Sync for TakeAny<I>

impl<I> Unpin for TakeAny<I>

impl<I> UnsafeUnpin for TakeAny<I>

impl<I> UnwindSafe for TakeAny<I>

impl<I: $crate::clone::Clone + ParallelIterator> Clone for TakeAny<I>

fn clone(self: &Self) -> TakeAny<I>

impl<I: $crate::fmt::Debug + ParallelIterator> Debug for TakeAny<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for TakeAny<I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TakeAny<I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TakeAny<I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TakeAny<I>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for TakeAny<I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoParallelIterator for TakeAny<I>

fn into_par_iter(self: Self) -> T

impl<T> Pointable for TakeAny<I>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for TakeAny<I>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for TakeAny<I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TakeAny<I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TakeAny<I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>