Struct TakeAnyWhile
struct TakeAnyWhile<I: ParallelIterator, P> { ... }
TakeAnyWhile is an iterator that iterates over elements from anywhere in I
until the callback returns false.
This struct is created by the take_any_while() method on ParallelIterator
Implementations
impl<I, P> Freeze for TakeAnyWhile<I, P>
impl<I, P> ParallelIterator for TakeAnyWhile<I, P>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>
impl<I, P> RefUnwindSafe for TakeAnyWhile<I, P>
impl<I, P> Send for TakeAnyWhile<I, P>
impl<I, P> Sync for TakeAnyWhile<I, P>
impl<I, P> Unpin for TakeAnyWhile<I, P>
impl<I, P> UnsafeUnpin for TakeAnyWhile<I, P>
impl<I, P> UnwindSafe for TakeAnyWhile<I, P>
impl<I: $crate::clone::Clone + ParallelIterator, P: $crate::clone::Clone> Clone for TakeAnyWhile<I, P>
fn clone(self: &Self) -> TakeAnyWhile<I, P>
impl<I: ParallelIterator + fmt::Debug, P> Debug for TakeAnyWhile<I, P>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for TakeAnyWhile<I, P>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for TakeAnyWhile<I, P>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for TakeAnyWhile<I, P>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for TakeAnyWhile<I, P>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for TakeAnyWhile<I, P>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for TakeAnyWhile<I, P>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for TakeAnyWhile<I, P>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for TakeAnyWhile<I, P>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for TakeAnyWhile<I, P>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for TakeAnyWhile<I, P>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for TakeAnyWhile<I, P>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>