Struct TryFold

struct TryFold<I, U, ID, F> { ... }

TryFold is an iterator that applies a function over an iterator producing a single value. This struct is created by the try_fold() method on ParallelIterator

Implementations

impl<I, U, ID, F> Freeze for TryFold<I, U, ID, F>

impl<I, U, ID, F> RefUnwindSafe for TryFold<I, U, ID, F>

impl<I, U, ID, F> Send for TryFold<I, U, ID, F>

impl<I, U, ID, F> Sync for TryFold<I, U, ID, F>

impl<I, U, ID, F> Unpin for TryFold<I, U, ID, F>

impl<I, U, ID, F> UnsafeUnpin for TryFold<I, U, ID, F>

impl<I, U, ID, F> UnwindSafe for TryFold<I, U, ID, F>

impl<I: $crate::clone::Clone, U: $crate::clone::Clone, ID: $crate::clone::Clone, F: $crate::clone::Clone> Clone for TryFold<I, U, ID, F>

fn clone(self: &Self) -> TryFold<I, U, ID, F>

impl<T> Any for TryFold<I, U, ID, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for TryFold<I, U, ID, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for TryFold<I, U, ID, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for TryFold<I, U, ID, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for TryFold<I, U, ID, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoParallelIterator for TryFold<I, U, ID, F>

fn into_par_iter(self: Self) -> T

impl<T> Pointable for TryFold<I, U, ID, F>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for TryFold<I, U, ID, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for TryFold<I, U, ID, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for TryFold<I, U, ID, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for TryFold<I, U, ID, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<U, I, ID, F> ParallelIterator for TryFold<I, U, ID, F>

fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: UnindexedConsumer<<Self as >::Item>

impl<U, I: ParallelIterator + Debug, ID, F> Debug for TryFold<I, U, ID, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result