Struct TryFoldWith
struct TryFoldWith<I, U: Try, F> { ... }
TryFoldWith is an iterator that applies a function over an iterator producing a single value.
This struct is created by the try_fold_with() method on ParallelIterator
Implementations
impl<I, U, F> Freeze for TryFoldWith<I, U, F>
impl<I, U, F> RefUnwindSafe for TryFoldWith<I, U, F>
impl<I, U, F> Send for TryFoldWith<I, U, F>
impl<I, U, F> Sync for TryFoldWith<I, U, F>
impl<I, U, F> Unpin for TryFoldWith<I, U, F>
impl<I, U, F> UnsafeUnpin for TryFoldWith<I, U, F>
impl<I, U, F> UnwindSafe for TryFoldWith<I, U, F>
impl<I: $crate::clone::Clone, U: $crate::clone::Clone + Try, F: $crate::clone::Clone> Clone for TryFoldWith<I, U, F>
fn clone(self: &Self) -> TryFoldWith<I, U, F>
impl<I: ParallelIterator + Debug, U: Try, F> Debug for TryFoldWith<I, U, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for TryFoldWith<I, U, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for TryFoldWith<I, U, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for TryFoldWith<I, U, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for TryFoldWith<I, U, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for TryFoldWith<I, U, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for TryFoldWith<I, U, F>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for TryFoldWith<I, U, F>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for TryFoldWith<I, U, F>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for TryFoldWith<I, U, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for TryFoldWith<I, U, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for TryFoldWith<I, U, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<U, I, F> ParallelIterator for TryFoldWith<I, U, F>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>