Struct WhileSome
struct WhileSome<I: ParallelIterator> { ... }
WhileSome is an iterator that yields the Some elements of an iterator,
halting as soon as any None is produced.
This struct is created by the while_some() method on ParallelIterator
Implementations
impl<I> Freeze for WhileSome<I>
impl<I> RefUnwindSafe for WhileSome<I>
impl<I> Send for WhileSome<I>
impl<I> Sync for WhileSome<I>
impl<I> Unpin for WhileSome<I>
impl<I> UnsafeUnpin for WhileSome<I>
impl<I> UnwindSafe for WhileSome<I>
impl<I, T> ParallelIterator for WhileSome<I>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>
impl<I: $crate::clone::Clone + ParallelIterator> Clone for WhileSome<I>
fn clone(self: &Self) -> WhileSome<I>
impl<I: $crate::fmt::Debug + ParallelIterator> Debug for WhileSome<I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for WhileSome<I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for WhileSome<I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for WhileSome<I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for WhileSome<I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for WhileSome<I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for WhileSome<I>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for WhileSome<I>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for WhileSome<I>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for WhileSome<I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for WhileSome<I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for WhileSome<I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>