Struct ChunksExact
struct ChunksExact<'data, T: Sync> { ... }
Parallel iterator over immutable non-overlapping chunks of a slice
Implementations
impl<'data, T: Sync> ChunksExact<'data, T>
fn remainder(self: &Self) -> &'data [T]Return the remainder of the original slice that is not going to be returned by the iterator. The returned slice has at most
chunk_size-1elements.
impl<'data, T> Freeze for ChunksExact<'data, T>
impl<'data, T> RefUnwindSafe for ChunksExact<'data, T>
impl<'data, T> Send for ChunksExact<'data, T>
impl<'data, T> Sync for ChunksExact<'data, T>
impl<'data, T> Unpin for ChunksExact<'data, T>
impl<'data, T> UnsafeUnpin for ChunksExact<'data, T>
impl<'data, T> UnwindSafe for ChunksExact<'data, T>
impl<'data, T: $crate::fmt::Debug + Sync> Debug for ChunksExact<'data, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'data, T: Sync + 'data> IndexedParallelIterator for ChunksExact<'data, T>
fn drive<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<<Self as >::Item>fn len(self: &Self) -> usizefn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<'data, T: Sync + 'data> ParallelIterator for ChunksExact<'data, T>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<'data, T: Sync> Clone for ChunksExact<'data, T>
fn clone(self: &Self) -> Self
impl<T> Any for ChunksExact<'data, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ChunksExact<'data, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ChunksExact<'data, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ChunksExact<'data, T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ChunksExact<'data, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for ChunksExact<'data, T>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for ChunksExact<'data, T>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for ChunksExact<'data, T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ChunksExact<'data, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ChunksExact<'data, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ChunksExact<'data, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>