Function empty
fn empty<T: Send>() -> Empty<T>
Creates a parallel iterator that produces nothing.
This admits no parallelism on its own, but it could be used for code that deals with generic parallel iterators.
Examples
use *;
use empty;
let pi = .into_par_iter
.chain
.chain;
assert_eq!;