Function repeat
fn repeat<T: Clone + Send>(elt: T) -> Repeat<T>
Creates a parallel iterator that endlessly repeats elt (by
cloning it). Note that this iterator has "infinite" length, so
typically you would want to use zip or take or some other
means to shorten it, or consider using
the repeatn() function instead.
Examples
use *;
use repeat;
let x: = repeat.zip.collect;
assert_eq!;