Struct Chain
struct Chain<A, B> { ... }
where
A: ParallelIterator,
B: ParallelIterator<Item = <A as >::Item>
Chain is an iterator that joins b after a in one continuous iterator.
This struct is created by the chain() method on ParallelIterator
Implementations
impl<A, B> Clone for Chain<A, B>
fn clone(self: &Self) -> Chain<A, B>
impl<A, B> Debug for Chain<A, B>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<A, B> Freeze for Chain<A, B>
impl<A, B> IndexedParallelIterator for Chain<A, B>
fn drive<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<<Self as >::Item>fn len(self: &Self) -> usizefn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<A, B> ParallelIterator for Chain<A, B>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<A, B> RefUnwindSafe for Chain<A, B>
impl<A, B> Send for Chain<A, B>
impl<A, B> Sync for Chain<A, B>
impl<A, B> Unpin for Chain<A, B>
impl<A, B> UnsafeUnpin for Chain<A, B>
impl<A, B> UnwindSafe for Chain<A, B>
impl<T> Any for Chain<A, B>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Chain<A, B>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Chain<A, B>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Chain<A, B>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Chain<A, B>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for Chain<A, B>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for Chain<A, B>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for Chain<A, B>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Chain<A, B>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Chain<A, B>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Chain<A, B>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>