Struct Flatten
struct Flatten<I: ParallelIterator> { ... }
Flatten turns each element to a parallel iterator, then flattens these iterators
together. This struct is created by the flatten() method on ParallelIterator.
Implementations
impl<I> Freeze for Flatten<I>
impl<I> ParallelIterator for Flatten<I>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>
impl<I> RefUnwindSafe for Flatten<I>
impl<I> Send for Flatten<I>
impl<I> Sync for Flatten<I>
impl<I> Unpin for Flatten<I>
impl<I> UnsafeUnpin for Flatten<I>
impl<I> UnwindSafe for Flatten<I>
impl<I: $crate::clone::Clone + ParallelIterator> Clone for Flatten<I>
fn clone(self: &Self) -> Flatten<I>
impl<I: $crate::fmt::Debug + ParallelIterator> Debug for Flatten<I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Flatten<I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Flatten<I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Flatten<I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Flatten<I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Flatten<I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for Flatten<I>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for Flatten<I>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for Flatten<I>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Flatten<I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Flatten<I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Flatten<I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>