Struct Fold
struct Fold<I, ID, F> { ... }
Fold is an iterator that applies a function over an iterator producing a single value.
This struct is created by the fold() method on ParallelIterator
Implementations
impl<I, ID, F> Freeze for Fold<I, ID, F>
impl<I, ID, F> RefUnwindSafe for Fold<I, ID, F>
impl<I, ID, F> Send for Fold<I, ID, F>
impl<I, ID, F> Sync for Fold<I, ID, F>
impl<I, ID, F> Unpin for Fold<I, ID, F>
impl<I, ID, F> UnsafeUnpin for Fold<I, ID, F>
impl<I, ID, F> UnwindSafe for Fold<I, ID, F>
impl<I: $crate::clone::Clone, ID: $crate::clone::Clone, F: $crate::clone::Clone> Clone for Fold<I, ID, F>
fn clone(self: &Self) -> Fold<I, ID, F>
impl<I: ParallelIterator + Debug, ID, F> Debug for Fold<I, ID, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Fold<I, ID, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Fold<I, ID, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Fold<I, ID, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Fold<I, ID, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Fold<I, ID, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for Fold<I, ID, F>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for Fold<I, ID, F>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for Fold<I, ID, F>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Fold<I, ID, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Fold<I, ID, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Fold<I, ID, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<U, I, ID, F> ParallelIterator for Fold<I, ID, F>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>