Struct Map
struct Map<I: ParallelIterator, F> { ... }
Map is an iterator that transforms the elements of an underlying iterator.
This struct is created by the map() method on ParallelIterator
Implementations
impl<I, F> Freeze for Map<I, F>
impl<I, F> RefUnwindSafe for Map<I, F>
impl<I, F> Send for Map<I, F>
impl<I, F> Sync for Map<I, F>
impl<I, F> Unpin for Map<I, F>
impl<I, F> UnsafeUnpin for Map<I, F>
impl<I, F> UnwindSafe for Map<I, F>
impl<I, F, R> IndexedParallelIterator for Map<I, F>
fn drive<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<<Self as >::Item>fn len(self: &Self) -> usizefn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<I, F, R> ParallelIterator for Map<I, F>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<I: $crate::clone::Clone + ParallelIterator, F: $crate::clone::Clone> Clone for Map<I, F>
fn clone(self: &Self) -> Map<I, F>
impl<I: ParallelIterator + Debug, F> Debug for Map<I, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Map<I, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Map<I, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Map<I, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Map<I, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Map<I, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for Map<I, F>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for Map<I, F>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for Map<I, F>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Map<I, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Map<I, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Map<I, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>