Struct MinLen
struct MinLen<I: IndexedParallelIterator> { ... }
MinLen is an iterator that imposes a minimum length on iterator splits.
This struct is created by the with_min_len() method on IndexedParallelIterator
Implementations
impl<I> Freeze for MinLen<I>
impl<I> IndexedParallelIterator for MinLen<I>
fn drive<C: Consumer<<Self as >::Item>>(self: Self, consumer: C) -> <C as >::Resultfn len(self: &Self) -> usizefn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<I> ParallelIterator for MinLen<I>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<I> RefUnwindSafe for MinLen<I>
impl<I> Send for MinLen<I>
impl<I> Sync for MinLen<I>
impl<I> Unpin for MinLen<I>
impl<I> UnsafeUnpin for MinLen<I>
impl<I> UnwindSafe for MinLen<I>
impl<I: $crate::clone::Clone + IndexedParallelIterator> Clone for MinLen<I>
fn clone(self: &Self) -> MinLen<I>
impl<I: $crate::fmt::Debug + IndexedParallelIterator> Debug for MinLen<I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for MinLen<I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for MinLen<I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for MinLen<I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for MinLen<I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for MinLen<I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for MinLen<I>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for MinLen<I>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for MinLen<I>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for MinLen<I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for MinLen<I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for MinLen<I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>