Struct PanicFuse
struct PanicFuse<I: ParallelIterator> { ... }
PanicFuse is an adaptor that wraps an iterator with a fuse in case
of panics, to halt all threads as soon as possible.
This struct is created by the panic_fuse() method on ParallelIterator
Implementations
impl<I> Freeze for PanicFuse<I>
impl<I> IndexedParallelIterator for PanicFuse<I>
fn drive<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<<Self as >::Item>fn len(self: &Self) -> usizefn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<I> ParallelIterator for PanicFuse<I>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<I> RefUnwindSafe for PanicFuse<I>
impl<I> Send for PanicFuse<I>
impl<I> Sync for PanicFuse<I>
impl<I> Unpin for PanicFuse<I>
impl<I> UnsafeUnpin for PanicFuse<I>
impl<I> UnwindSafe for PanicFuse<I>
impl<I: $crate::clone::Clone + ParallelIterator> Clone for PanicFuse<I>
fn clone(self: &Self) -> PanicFuse<I>
impl<I: $crate::fmt::Debug + ParallelIterator> Debug for PanicFuse<I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for PanicFuse<I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PanicFuse<I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PanicFuse<I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for PanicFuse<I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for PanicFuse<I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for PanicFuse<I>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for PanicFuse<I>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for PanicFuse<I>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for PanicFuse<I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PanicFuse<I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PanicFuse<I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>