Struct Repeat
struct Repeat<T: Clone + Send> { ... }
Iterator adaptor for the repeat() function.
Implementations
impl<T> Repeat<T>
fn take(self: Self, n: usize) -> RepeatN<T>Takes only
nrepeats of the element, similar to the generaltake().The resulting
RepeatNis anIndexedParallelIterator, allowing more functionality thanRepeatalone.fn zip<Z>(self: Self, zip_op: Z) -> Zip<RepeatN<T>, <Z as >::Iter> where Z: IntoParallelIterator, <Z as >::Iter: IndexedParallelIteratorIterates tuples, repeating the element with items from another iterator, similar to the general
zip().
impl<T> Any for Repeat<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Repeat<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Repeat<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Repeat<T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> Freeze for Repeat<T>
impl<T> From for Repeat<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for Repeat<T>
fn into_par_iter(self: Self) -> T
impl<T> ParallelIterator for Repeat<T>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>
impl<T> Pointable for Repeat<T>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> RefUnwindSafe for Repeat<T>
impl<T> Send for Repeat<T>
impl<T> Sync for Repeat<T>
impl<T> ToOwned for Repeat<T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> Unpin for Repeat<T>
impl<T> UnsafeUnpin for Repeat<T>
impl<T> UnwindSafe for Repeat<T>
impl<T, U> Into for Repeat<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Repeat<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Repeat<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: $crate::clone::Clone + Clone + Send> Clone for Repeat<T>
fn clone(self: &Self) -> Repeat<T>
impl<T: $crate::fmt::Debug + Clone + Send> Debug for Repeat<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result