Struct Skip
struct Skip<I> { ... }
Skip is an iterator that skips over the first n elements.
This struct is created by the skip() method on IndexedParallelIterator
Implementations
impl<I> Freeze for Skip<I>
impl<I> IndexedParallelIterator for Skip<I>
fn len(self: &Self) -> usizefn drive<C: Consumer<<Self as >::Item>>(self: Self, consumer: C) -> <C as >::Resultfn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<I> ParallelIterator for Skip<I>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<I> RefUnwindSafe for Skip<I>
impl<I> Send for Skip<I>
impl<I> Sync for Skip<I>
impl<I> Unpin for Skip<I>
impl<I> UnsafeUnpin for Skip<I>
impl<I> UnwindSafe for Skip<I>
impl<I: $crate::clone::Clone> Clone for Skip<I>
fn clone(self: &Self) -> Skip<I>
impl<I: $crate::fmt::Debug> Debug for Skip<I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Skip<I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Skip<I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Skip<I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Skip<I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Skip<I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for Skip<I>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for Skip<I>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for Skip<I>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Skip<I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Skip<I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Skip<I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>