Struct Update

struct Update<I: ParallelIterator, F> { ... }

Update is an iterator that mutates the elements of an underlying iterator before they are yielded.

This struct is created by the update() method on ParallelIterator

Implementations

impl<I, F> Freeze for Update<I, F>

impl<I, F> IndexedParallelIterator for Update<I, F>

fn drive<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: Consumer<<Self as >::Item>
fn len(self: &Self) -> usize
fn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output
where
    CB: ProducerCallback<<Self as >::Item>

impl<I, F> ParallelIterator for Update<I, F>

fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result
where
    C: UnindexedConsumer<<Self as >::Item>
fn opt_len(self: &Self) -> Option<usize>

impl<I, F> RefUnwindSafe for Update<I, F>

impl<I, F> Send for Update<I, F>

impl<I, F> Sync for Update<I, F>

impl<I, F> Unpin for Update<I, F>

impl<I, F> UnsafeUnpin for Update<I, F>

impl<I, F> UnwindSafe for Update<I, F>

impl<I: $crate::clone::Clone + ParallelIterator, F: $crate::clone::Clone> Clone for Update<I, F>

fn clone(self: &Self) -> Update<I, F>

impl<I: ParallelIterator + Debug, F> Debug for Update<I, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Update<I, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Update<I, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Update<I, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Update<I, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Update<I, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> IntoParallelIterator for Update<I, F>

fn into_par_iter(self: Self) -> T

impl<T> Pointable for Update<I, F>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for Update<I, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Update<I, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Update<I, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Update<I, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>