Struct Zip
struct Zip<A: IndexedParallelIterator, B: IndexedParallelIterator> { ... }
Zip is an iterator that zips up a and b into a single iterator
of pairs. This struct is created by the zip() method on
IndexedParallelIterator
Implementations
impl<A, B> Freeze for Zip<A, B>
impl<A, B> IndexedParallelIterator for Zip<A, B>
fn drive<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<<Self as >::Item>fn len(self: &Self) -> usizefn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<A, B> ParallelIterator for Zip<A, B>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<A, B> RefUnwindSafe for Zip<A, B>
impl<A, B> Send for Zip<A, B>
impl<A, B> Sync for Zip<A, B>
impl<A, B> Unpin for Zip<A, B>
impl<A, B> UnsafeUnpin for Zip<A, B>
impl<A, B> UnwindSafe for Zip<A, B>
impl<A: $crate::clone::Clone + IndexedParallelIterator, B: $crate::clone::Clone + IndexedParallelIterator> Clone for Zip<A, B>
fn clone(self: &Self) -> Zip<A, B>
impl<A: $crate::fmt::Debug + IndexedParallelIterator, B: $crate::fmt::Debug + IndexedParallelIterator> Debug for Zip<A, B>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for Zip<A, B>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Zip<A, B>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Zip<A, B>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Zip<A, B>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Zip<A, B>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for Zip<A, B>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for Zip<A, B>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for Zip<A, B>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Zip<A, B>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Zip<A, B>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Zip<A, B>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>