Struct ZipEq
struct ZipEq<A: IndexedParallelIterator, B: IndexedParallelIterator> { ... }
An IndexedParallelIterator that iterates over two parallel iterators of equal
length simultaneously.
This struct is created by the zip_eq method on IndexedParallelIterator,
see its documentation for more information.
Implementations
impl<A, B> Freeze for ZipEq<A, B>
impl<A, B> IndexedParallelIterator for ZipEq<A, B>
fn drive<C>(self: Self, consumer: C) -> <C as >::Result where C: Consumer<<Self as >::Item>fn len(self: &Self) -> usizefn with_producer<CB>(self: Self, callback: CB) -> <CB as >::Output where CB: ProducerCallback<<Self as >::Item>
impl<A, B> ParallelIterator for ZipEq<A, B>
fn drive_unindexed<C>(self: Self, consumer: C) -> <C as >::Result where C: UnindexedConsumer<<Self as >::Item>fn opt_len(self: &Self) -> Option<usize>
impl<A, B> RefUnwindSafe for ZipEq<A, B>
impl<A, B> Send for ZipEq<A, B>
impl<A, B> Sync for ZipEq<A, B>
impl<A, B> Unpin for ZipEq<A, B>
impl<A, B> UnsafeUnpin for ZipEq<A, B>
impl<A, B> UnwindSafe for ZipEq<A, B>
impl<A: $crate::clone::Clone + IndexedParallelIterator, B: $crate::clone::Clone + IndexedParallelIterator> Clone for ZipEq<A, B>
fn clone(self: &Self) -> ZipEq<A, B>
impl<A: $crate::fmt::Debug + IndexedParallelIterator, B: $crate::fmt::Debug + IndexedParallelIterator> Debug for ZipEq<A, B>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for ZipEq<A, B>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ZipEq<A, B>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ZipEq<A, B>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ZipEq<A, B>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ZipEq<A, B>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> IntoParallelIterator for ZipEq<A, B>
fn into_par_iter(self: Self) -> T
impl<T> Pointable for ZipEq<A, B>
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for ZipEq<A, B>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ZipEq<A, B>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ZipEq<A, B>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ZipEq<A, B>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>